@@ -8,7 +8,6 @@
     :copyright: 2020 ISCLUB
     :license: MIT LICENSE
 """
-import cssutils
 
 
 class OnlyText(object):
@@ -23,6 +22,12 @@ class Record(object):
         self.classlist = classlist
         self.attrs = attrs
 
+        if not isinstance(self.body, list):
+            raise TypeError("Body must be a List.")
+
+        if not isinstance(self.classlist, list):
+            raise TypeError("Classlist must be a List.")
+
     def add(self, o):
         self.body.append(o)
 
